@@ -975,6 +975,8 @@ class WordToken(caching.base.CachingMixin,models.Model):
         return True
 
     def getCelexCat(self):
+        if self.Output is None:
+            self.Output = {}
         if 'CelexCategory' not in self.Output:
             cat = lookupCat(self.WordType.Label)
             self.Output['CelexCategory'] = cat
